@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: misc.pl,v 1.2 1999/06/10 19:29:18 root Exp root $
+# $Id: misc.pl,v 1.5 1999/09/05 12:10:46 root Exp root $
 
 # Copyright (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the LGPL. 
@@ -21,7 +21,7 @@ sub abs_path {
     chdir $path ;
     $path = cwd ;
 
-    $path =~ s!/./!/!go ;
+    $path =~ s!/\./!/!go ;
 
     if( $filename ) {
         $path .= '/' unless substr( $path, -1, 1 ) eq '/' ;
@@ -32,14 +32,11 @@ sub abs_path {
 }
 
 
-# Based on the example in The Perl Cookbook, but doesn't commify the year in
-# dates, i.e. leave 20/7/2004 in tact.
+# Copied from The Perl Cookbook
 sub commify {
     my $num = reverse $_[0] ;
     $num =~ s/(\d\d\d)(?=\d)(?!\d*\.)/$1,/g ;
-    $num = scalar reverse $num ;
-    $num =~ s!(/\d),!$1!go ;
-    $num ;
+    scalar reverse $num ;
 }
 
 
